;;; set-compile-command.el -- tool to set compile-command
;;; $Id$

;; Author: Taka Ogawa <xia@mule.club.ne.jp>

;;; Commentary:
;; compile-command を Makefile の有無や major-mode に応じて設定します。
;; 	(make-variable-buffer-local 'compile-command)
;; 	(setq-default compile-command '(set-compile-command))
;; という使い方を想定しています。
;; major-mode との対応は compile-command-mode-specific で。
;; 	(setq compile-command-mode-specific
;; 	      '((emacs-lisp-mode . ((flags . "-f ~/share/mk/elisp.mk")
;; 				    (ext . ".elc")))))
;; とか。

;;; Code:
(defvar compile-command-mode-specific '())
(defvar compile-command-make "make")
(defvar compile-command-makefile "Makefile")

(defun compile-command-function ()
  (let ((alist (cdr (assq major-mode compile-command-mode-specific))))
    (if (and alist
	     buffer-file-name
	     (null (file-exists-p compile-command-makefile)))
	(format "%s %s %s%s"
		(or (cdr (assq 'command alist)) compile-command-make)
		(or (cdr (assq 'flags alist)) "")
		(file-name-sans-extension
		 (file-name-nondirectory buffer-file-name))
		(or (cdr (assq 'ext alist))
		    (file-name-extension buffer-file-name)))
      (format "%s " compile-command-make))))

(defun set-compile-command ()
  (setq compile-command (compile-command-function)))

(provide 'set-compile-command)

;;; set-compile-command.el ends here
